@@ -65,27 +65,6 @@ BatteryModel::BatteryModel(QObject *parent) : QAbstractListModel(parent)
     });
 }
 
-Solid::Battery *BatteryModel::get(int index) const
-{
-    if (index < 0 || index >= m_batteries.count()) {
-        return nullptr;
-    }
-
-    Solid::Battery* battery = m_batteries.value(index).as<Solid::Battery>();
-
-    QQmlEngine::setObjectOwnership(battery, QQmlEngine::CppOwnership);
-    return battery;
-}
-
-QString BatteryModel::udi(int index) const
-{
-    if (index < 0 || index >= m_batteries.count()) {
-        return QString();
-    }
-
-    return m_batteries.at(index).udi();
-}
-
 QVariant BatteryModel::data(const QModelIndex &index, int role) const
 {
     if (index.row() < 0 || index.row() >= m_batteries.count()) {
@@ -94,6 +73,12 @@ QVariant BatteryModel::data(const QModelIndex &index, int role) const
 
     if (role == BatteryRole) {
         return QVariant::fromValue(m_batteries.value(index.row()).as<Solid::Battery>());
+    } else if (role == ProductRole) {
+        const Solid::Device device = m_batteries.value(index.row());
+        return device.product();
+    } else if (role == VendorRole) {
+        const Solid::Device device = m_batteries.value(index.row());
+        return device.vendor();
     } else if (role == UdiRole) {
         return m_batteries.at(index.row()).udi();
     }
@@ -111,6 +96,8 @@ QHash<int, QByteArray> BatteryModel::roleNames() const
 {
     return {
         {BatteryRole, "battery"},
+        {VendorRole, "vendor"},
+        {ProductRole, "product"},
         {UdiRole, "udi"}
     };
 }
